@@ -9,7 +9,6 @@ exports["Asia/Ulaanbaatar"] = {
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ulaanbaatar", { abbr: true, expect: "Asia/Manila" }),
 
 	"1905" : helpers.makeTestYear("Asia/Ulaanbaatar", [
-		["1905-07-31T16:52:27+00:00", "23:59:59", "LMT", -25652 / 60],
 		["1905-07-31T16:52:28+00:00", "23:52:28", "+07", -420]
 	]),
 
@@ -182,7 +181,6 @@ exports["Asia/Ulaanbaatar"] = {
 	"2016" : helpers.makeTestYear("Asia/Ulaanbaatar", [
 		["2016-03-25T17:59:59+00:00", "01:59:59", "+08", -480],
 		["2016-03-25T18:00:00+00:00", "03:00:00", "+09", -540],
-		["2016-09-23T14:59:59+00:00", "23:59:59", "+09", -540],
-		["2016-09-23T15:00:00+00:00", "23:00:00", "+08", -480]
+		["2016-09-23T14:59:59+00:00", "23:59:59", "+09", -540]
 	])
 };
\ No newline at end of file
